@@ -1,36 +1,23 @@
 import json
 import os
 import webbrowser
-from typing import Any, Dict
+from typing import Any
 
 import fire
 import tweepy
 
 BASE_URL = "https://api.twitter.com/"
-ROOT_PATH = os.environ["HOME"] + "/.local/clitw"
+ROOT_PATH = os.environ["HOME"] + "/clitw"
 TOKEN_FILE = ROOT_PATH + "/oauth_token.json"
-CONSUMER_FILE = ROOT_PATH + "/consumer_api.json"
+CONSUMER_FILE = ROOT_PATH + "/consumer_token.json"
 
 
 def make_auth() -> Any:
-    if os.path.isfile(CONSUMER_FILE):
-        with open(CONSUMER_FILE, "r") as f:
-            consumer = json.load(f)
-    else:
-        consumer = register_consumer()
-
+    with open(CONSUMER_FILE, mode="+r") as f:
+        consumer = json.load(f)
     return tweepy.OAuthHandler(**consumer)
 
 
-def register_consumer() -> Dict[str, str]:
-    consumer_key = input("Consumer key: ")
-    consumer_secret = input("Consumer secret: ")
-    consumer = {"consumer_key": consumer_key, "consumer_secret": consumer_secret}
-    with open(CONSUMER_FILE, "w") as f:
-        json.dump(consumer, f)
-    return consumer
-
-
 def authenicate_oauth(auth: Any) -> str:
     try:
         redirect_url = auth.get_authorization_url()
@@ -38,8 +25,7 @@ def authenicate_oauth(auth: Any) -> str:
         raise tweepy.TweepError(e)
 
     if webbrowser.open_new_tab(redirect_url):
-        verifier = input("Verifier: ")
-        return verifier
+        return input("Verifier: ")
     else:
         raise ValueError()
 
@@ -69,15 +55,14 @@ def make_api() -> Any:
 
 
 class Twitter:
-    def __init__(self,) -> None:
-        if os.path.isdir(ROOT_PATH):
-            pass
-        else:
+    def __init__(self) -> None:
+        if not os.path.isdir(ROOT_PATH):
             os.makedirs(ROOT_PATH)
         self.api = make_api()
 
     def tw(self) -> None:
         flag = "n"
+        text = ""
         while flag != "y":
             text = input("Text: ")
             print(text)
@@ -89,5 +74,5 @@ class Twitter:
         print("success")
 
 
-def main():
+def main() -> None:
     fire.Fire(Twitter)
